@@ -1,6 +1,6 @@
 from selenium import webdriver
 
-def what():
+def upload():
     driver = webdriver.Chrome('chromedriver.exe')
     driver.get("https://web.whatsapp.com/")
     driver.maximize_window()
